@@ -1,14 +1,17 @@
 /* ISC license. */
 
-#include <sys/stat.h>
+#include <skalibs/bsdsnowflake.h>
+
 #include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
 #include <regex.h>
 
 #include <skalibs/posixplz.h>
+#include <skalibs/stat.h>
 #include <skalibs/types.h>
 #include <skalibs/strerr.h>
+#include <skalibs/djbtime.h>
 #include <skalibs/djbunix.h>
 
 enum eltest_opnum_e
@@ -360,7 +363,7 @@ static int eltest_run (struct eltest_node_s const *tree, unsigned int root)
     {
       struct stat st ;
       if (stat(tree[tree[root].arg1].data, &st) == -1) return 0 ;
-      return (st.st_mtime > st.st_atime) ;
+      return timespec_cmp(&st.st_mtim, &st.st_atim) > 0 ;
     }
     case T_EUID :
     {
@@ -385,14 +388,14 @@ static int eltest_run (struct eltest_node_s const *tree, unsigned int root)
       struct stat st1, st2 ;
       if (stat(tree[tree[root].arg1].data, &st1) == -1) return 0 ;
       if (stat(tree[tree[root].arg2].data, &st2) == -1) return 1 ;
-      return st1.st_mtime > st2.st_mtime ;
+      return timespec_cmp(&st1.st_mtim, &st2.st_mtim) > 0 ;
     }
     case T_OLDER :
     {
       struct stat st1, st2 ;
       if (stat(tree[tree[root].arg1].data, &st1) == -1) return 1 ;
       if (stat(tree[tree[root].arg2].data, &st2) == -1) return 0 ;
-      return st1.st_mtime < st2.st_mtime ;
+      return timespec_cmp(&st1.st_mtim, &st2.st_mtim) < 0 ;
     }
     case T_DEVINO :
     {
