@@ -19,9 +19,9 @@
 #define USAGE "forstdin [ -E | -e ] [ -p | -o okcode,okcode,... | -x breakcode,breakcode,... ] [ -N | -n ] [ -C | -c ] [ -0 | -d delim ] var command..."
 #define dieusage() strerr_dieusage(100, USAGE)
 
-static genalloc pids = GENALLOC_ZERO ; /* pid_t */
+static genalloc *forstdin_pids_p = 0 ;  /* minimize bss/data */
 
-static int isok (unsigned short *tab, unsigned int n, int code)
+static int fs_isok (unsigned short *tab, unsigned int n, int code)
 {
   unsigned int i = 0 ;
   for (; i < n ; i++) if ((unsigned short)code == tab[i]) break ;
@@ -30,8 +30,8 @@ static int isok (unsigned short *tab, unsigned int n, int code)
 
 static void parallel_sigchld_handler (int sig)
 {
-  pid_t *tab = genalloc_s(pid_t, &pids) ;
-  size_t len = genalloc_len(pid_t, &pids) ;
+  pid_t *tab = genalloc_s(pid_t, forstdin_pids_p) ;
+  size_t len = genalloc_len(pid_t, forstdin_pids_p) ;
   int wstat ;
   for (;;)
   {
@@ -39,12 +39,13 @@ static void parallel_sigchld_handler (int sig)
     if (r <= 0) break ;
     tab[r-1] = tab[--len] ;
   }
-  genalloc_setlen(pid_t, &pids, len) ;
+  genalloc_setlen(pid_t, forstdin_pids_p, len) ;
   (void)sig ;
 }
 
 int main (int argc, char const **argv)
 {
+  genalloc pids = GENALLOC_ZERO ;
   stralloc value = STRALLOC_ZERO ;
   char const *delim = "\n" ;
   size_t delimlen = 1 ;
@@ -52,6 +53,8 @@ int main (int argc, char const **argv)
   unsigned short okcodes[256] ;
   int crunch = 0, chomp = 1, not = 1, eofcode = 1, doimport = 0 ;
   PROG = "forstdin" ;
+  forstdin_pids_p = &pids ;
+
   {
     subgetopt l = SUBGETOPT_ZERO ;
     for (;;)
@@ -136,7 +139,7 @@ int main (int argc, char const **argv)
       int wstat ;
       if (wait_pid(pid, &wstat) < 0)
         strerr_diefu2sys(111, "wait for ", argv[1]) ;
-      if (not == isok(okcodes, nbc, wait_estatus(wstat)))
+      if (not == fs_isok(okcodes, nbc, wait_estatus(wstat)))
         return wait_estatus(wstat) ;
     }
   }
