@@ -1,6 +1,6 @@
 /* ISC license. */
 
-#include <skalibs/djbunix.h>
+#include <skalibs/cspawn.h>
 
 #include <execline/config.h>
 #include <execline/execline.h>
@@ -10,7 +10,7 @@ pid_t el_spawn0 (char const *prog, char const *const *argv, char const *const *e
   if (!argv[0])
   {
     static char const *const newargv[3] = { EXECLINE_BINPREFIX "exit", "0", 0 } ;
-    return child_spawn0(newargv[0], newargv, 0) ;
+    return cspawn(newargv[0], newargv, envp, 0, 0, 0) ;
   }
-  else return child_spawn0(prog, argv, envp) ;
+  else return cspawn(prog, argv, envp, 0, 0, 0) ;
 }
